==> haskell-hspec-expectations-0.8.3-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations
version:              0.8.3
visibility:           public
id:                   hspec-expectations-0.8.3-8SHeV75XzHGAS0nDpIhPfV
key:                  hspec-expectations-0.8.3-8SHeV75XzHGAS0nDpIhPfV
license:              MIT
copyright:            (c) 2011-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  1b4e8c9b1d3b2be01a27723f98d7bf21
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations
hs-libraries:         HShspec-expectations-0.8.3-8SHeV75XzHGAS0nDpIhPfV
depends:
    HUnit-1.6.2.0-DucYFi7W996LJfea0vxExR base-4.17.2.1
    call-stack-0.4.0-DB4dQQkTPQ5DiL3lPhgRb2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.3-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations
version:              0.8.3
visibility:           public
id:                   hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
key:                  hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
license:              MIT
copyright:            (c) 2011-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  d562cf5fbc26370a4eee98155379316f
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-expectations-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations
hs-libraries:         HShspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
